==> haskell-shakespeare-2.0.7-5-armv7h.pkg.tar.xz: usr/share/haskell/haskell-shakespeare/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.7
id: shakespeare-2.0.7-3d8247ff57d7f10558308bd73d118ae2
key: shake_7rwzrzQ3cb36tjPes1bbys
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: shakespeare-js, shakespeare-css, shakespeare-text, hamlet, and xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.7
hs-libraries: HSshakespeare-2.0.7-7rwzrzQ3cb36tjPes1bbys
depends:
    aeson-0.10.0.0-d37842f030fec47bc6e0ba2aef0f6571
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.6.0-2907cc2989779dea3b04f8a0a144a8a7
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-shakespeare-2.0.7-6-armv7h.pkg.tar.xz: usr/share/haskell/haskell-shakespeare/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: shakespeare
version: 2.0.7
id: shakespeare-2.0.7-423d40cf84610c6e09dcfa0707b6b283
key: shake_EuK2lX4rZQwEyZc4T7SYzq
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/shakespearean-templates
synopsis: A toolkit for making compile-time interpolated templates
description:
    Shakespeare is a family of type-safe, efficient template languages. Shakespeare templates are expanded at compile-time, ensuring that all interpolated variables are in scope. Variables are interpolated according to their type through a typeclass.
    .
    Shakespeare templates can be used inline with a quasi-quoter or in an external file.
    .
    Note there is no dependency on haskell-src-extras. Instead Shakespeare believes logic should stay out of templates and has its own minimal Haskell parser.
    .
    Packages that use this: shakespeare-js, shakespeare-css, shakespeare-text, hamlet, and xml-hamlet
    .
    Please see the documentation at <http://www.yesodweb.com/book/shakespearean-templates> for more details.
category: Web, Yesod
author: Michael Snoyman <michael@snoyman.com>
exposed: True
exposed-modules:
    Text.Shakespeare.I18N Text.Shakespeare.Text Text.Roy Text.Julius
    Text.Coffee Text.Hamlet Text.Hamlet.RT Text.Hamlet.Runtime
    Text.Lucius Text.Cassius Text.Shakespeare.Base Text.Shakespeare
    Text.TypeScript
hidden-modules: Text.Hamlet.Parse Text.Css Text.MkSizeType
                Text.IndentToBrace Text.CssCommon
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
library-dirs: /usr/lib/ghc-7.10.3/site-local/shakespeare-2.0.7
data-dir: /usr/share/arm-linux-ghc-7.10.3/shakespeare-2.0.7
hs-libraries: HSshakespeare-2.0.7-EuK2lX4rZQwEyZc4T7SYzq
depends:
    aeson-0.10.0.0-3aa334e096178e3f732c7fe0cfda35e7
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-html-0.8.1.1-59ea4b5f01886f370857b4d16361c2fc
    blaze-markup-0.7.0.3-4e4a97653c712eed9984271000636729
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    ghc-prim-0.4.0.0-bf246eb9fdda7435f0c147a313ce59fb
    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    scientific-0.3.4.4-3faa9d36abc45b55aed128d427a02fce
    template-haskell-2.10.0.0-4b92ab565139fd81021b60a162b59eb8
    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
    vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
haddock-interfaces: /usr/share/doc/haskell-shakespeare/html/shakespeare.haddock
haddock-html: /usr/share/doc/haskell-shakespeare/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
